<?php
// wcf imports
require_once(WCF_DIR.'lib/form/AbstractForm.class.php');
require_once(WCF_DIR.'lib/data/user/notification/NotificationHandler.class.php');
require_once(WCF_DIR.'lib/data/chat/ChatRoomEditor.class.php');
require_once(WCF_DIR.'lib/data/chat/ChatMessageEditor.class.php');

/**
 * Sends the invitation
 *
 * @author 	Tim Düsterhus
 * @copyright 	2011 Tim Düsterhus
 * @package 	timwolla.wcf.chat.invitation
 * @license 	Creative Commons BY-NC-ND <http://creativecommons.org/licenses/by-nc-nd/3.0/de/>
 */
class ChatInvitationForm extends AbstractForm {
	public $user = array();
	public $neededPermissions = 'user.chat.canInvite';
	
	/**
	 * @see Form::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		if (isset($_POST['user']) && is_array($_POST['user'])) $this->user = ArrayUtil::toIntegerArray($_POST['user']);
	}
	
	/**
	 * @see Page::show()
	 */
	public function show() {
		// break when chat is not active
		if (!CHAT_ACTIVE) throw new IllegalLinkException();
		if (!WCF::getUser()->userID) throw new PermissionDeniedException();
	
		parent::show();
	}
	
	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();
		
		$this->room = new ChatRoom(WCF::getUser()->chatlastroom);
		
		// notify them
		$values = array();
		foreach ($this->user as $user) {
			NotificationHandler::fireEvent('chatInvite', 'void', 0, $user, array('userID' => WCF::getUser()->userID, 'username' => WCF::getUser()->username, 'roomID' => $this->room->roomID));
			$values[] = "(".$this->room->roomID.", ".$user.", ".(TIME_NOW + 30).")";
		}
		
		// add invites if possible (even if the room is public)
		if (WCF::getUser()->getPermission('mod.chat.canInvite') || $this->room->userID == WCF::getUser()->userID) {
			$sql = "REPLACE INTO wcf".WCF_N."_chat_room_invite (roomID, userID, time)
				VALUES ".implode(',', $values);
			WCF::getDB()->sendQuery($sql);
		}

		// create success-message
		ChatMessageEditor::create(null, WCF::getUser()->username, WCF::getLanguage()->get('wcf.chat.invitation.success'), $this->room->roomID, WCF::getUser()->userID, ChatMessage::INFORMATION, '000000', '000000', false);
		$this->saved();
		exit;
	}
}
